==> blanco.plugin.stringgroup_0.1.1-eclipse3.0.zip: src/blanco/plugin/stringgroup/wizards/BlancoStringGroupWizardPage2.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.stringgroup.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.stringgroup.BlancoStringGroupConstants;
import blanco.stringgroup.resourcebundle.BlancoStringGroupResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoStringGroupWizardPage2 extends WizardPage {
    private static final BlancoStringGroupResourceBundle fBundle = new BlancoStringGroupResourceBundle();

    public BlancoStringGroupWizardPage2(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoStringGroupConstants.PRODUCT_NAME + "̏Љ");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText(BlancoStringGroupConstants.PRODUCT_NAME + " ͉L̂悤ȃc[łB");
        new Label(container, SWT.NONE).setText("  1.\[XR[h^Cv");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname()
                + "̋Lqeɑ\[XR[h܂B");
        new Label(container, SWT.NONE)
                .setText("    sɓ̃Cu(*.jar)t@CKvƂ܂B");
        new Label(container, SWT.NONE).setText("  2.hLgw");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "͂Ƃē삵܂B");
        new Label(container, SWT.NONE)
                .setText("    hLgwł邽߁AhLgƃ\[XR[hƂ̓RɎ邱Ƃo܂B");

        setControl(container);
    }
}

==> blanco.plugin.stringgroup_0.2.0-eclipse3.0.zip: src/blanco/plugin/stringgroup/wizards/BlancoStringGroupWizardPage2.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.stringgroup.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.stringgroup.BlancoStringGroupConstants;
import blanco.stringgroup.resourcebundle.BlancoStringGroupResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoStringGroupWizardPage2 extends WizardPage {
    private static final BlancoStringGroupResourceBundle fBundle = new BlancoStringGroupResourceBundle();

    public BlancoStringGroupWizardPage2(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoStringGroupConstants.PRODUCT_NAME + "̏Љ");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText(BlancoStringGroupConstants.PRODUCT_NAME
                        + " ͉L̂悤ȃc[łB");
        new Label(container, SWT.NONE).setText("  1.\[XR[h^Cv");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname()
                + "̋Lqeɑ\[XR[h܂B");
        new Label(container, SWT.NONE)
                .setText("    sɓ̃Cu(*.jar)t@CKvƂ܂B");
        new Label(container, SWT.NONE).setText("  2.hLgw");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "͂Ƃē삵܂B");
        new Label(container, SWT.NONE)
                .setText("    hLgwł邽߁AhLgƃ\[XR[hƂ̓RɎ邱Ƃo܂B");

        setControl(container);
    }
}
